local options = {}
local frame = CreateFrame("frame")
local config = CreateFrame("Frame")

local EU_REGION = "EU"
local US_REGION = "US"
local KR_REGION = "KR"
local TW_REGION = "TW"

local PlayerArmoryURL = ""

------------------------
-- HELPER functions
------------------------

frame:SetScript("OnEvent", function(self, event, ...)
    self[event](self, ...)
end)

local function getBoolean(val)
	if val then
		return true
	else
		return false
	end
end

function mySplit(inputstr, sep)
        if sep == nil then
                sep = "-"
        end
        local t={} ; i=1
        for str in string.gmatch(inputstr, "([^"..sep.."]+)") do
                t[i] = str
                i = i + 1
        end
        return t
end

------------------------
-- STATIC functions
------------------------

local function setupAMConfig(c)

	config.name = "ArmoryMe"
	
	config.title = config:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	config.title:SetFont(GameFontNormal:GetFont(), 20, "OUTLINE")
	config.title:SetPoint("TOPLEFT", config, 10, -10)
	config.title:SetText(config.name)
	
	
	config.title = config:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	config.title:SetFont(GameFontNormal:GetFont(), 16, "OUTLINE")
	config.title:SetPoint("TOPLEFT", config, 10, -55)
	config.title:SetText("Select region")
	
	
	config.eubox = CreateFrame("CheckButton", "AMenableButton", config, "InterfaceOptionsCheckButtonTemplate")
	config.eubox:SetPoint("TOPLEFT", config, 10, -85)
	config.eubox:SetHitRectInsets(0, -40, 0, 0)
	config.euboxtitle = config:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	config.euboxtitle:SetFont(GameFontNormal:GetFont(), 14, "OUTLINE")
	config.euboxtitle:SetPoint("LEFT", config.eubox, 30, 0)
	config.euboxtitle:SetText("|cffffffff" .. EU_REGION .. "|r")
	config.eubox.tooltip = "Select this if you are in "..EU_REGION
	
	config.usbox = CreateFrame("CheckButton", "AMenableButton", config, "InterfaceOptionsCheckButtonTemplate")
	config.usbox:SetPoint("TOPLEFT", config, 80, -85)
	config.usbox:SetHitRectInsets(0, -40, 0, 0)
	config.usboxtitle = config:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	config.usboxtitle:SetFont(GameFontNormal:GetFont(), 14, "OUTLINE")
	config.usboxtitle:SetPoint("LEFT", config.usbox, 30, 0)
	config.usboxtitle:SetText("|cffffffff" .. US_REGION .. "|r")
	config.usbox.tooltip = "Select this if you are in "..US_REGION
	
	config.krbox = CreateFrame("CheckButton", "AMenableButton", config, "InterfaceOptionsCheckButtonTemplate")
	config.krbox:SetPoint("TOPLEFT", config, 150, -85)
	config.krbox:SetHitRectInsets(0, -40, 0, 0)
	config.krboxtitle = config:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	config.krboxtitle:SetFont(GameFontNormal:GetFont(), 14, "OUTLINE")
	config.krboxtitle:SetPoint("LEFT", config.krbox, 30, 0)
	config.krboxtitle:SetText("|cffffffff" .. KR_REGION .. "|r")
	config.krbox.tooltip = "Select this if you are in "..KR_REGION
	
	config.twbox = CreateFrame("CheckButton", "AMenableButton", config, "InterfaceOptionsCheckButtonTemplate")
	config.twbox:SetPoint("TOPLEFT", config, 220, -85)
	config.twbox:SetHitRectInsets(0, -40, 0, 0)
	config.twboxtitle = config:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	config.twboxtitle:SetFont(GameFontNormal:GetFont(), 14, "OUTLINE")
	config.twboxtitle:SetPoint("LEFT", config.twbox, 30, 0)
	config.twboxtitle:SetText("|cffffffff" .. TW_REGION .. "|r")
	config.twbox.tooltip = "Select this if you are in "..TW_REGION
	
	config.title = config:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	config.title:SetFont(GameFontNormal:GetFont(), 16, "OUTLINE")
	config.title:SetPoint("TOPLEFT", config, 10, -125)
	config.title:SetText("Select type of armory")
	
	config.simple = CreateFrame("CheckButton", "AMenableButton", config, "InterfaceOptionsCheckButtonTemplate")
	config.simple:SetPoint("TOPLEFT", config, 10, -150)
	config.simple:SetHitRectInsets(0, -40, 0, 0)
	config.simpletitle = config:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	config.simpletitle:SetFont(GameFontNormal:GetFont(), 14, "OUTLINE")
	config.simpletitle:SetPoint("LEFT", config.simple, 30, 0)
	config.simpletitle:SetText("|cffffffff" .. "Simple" .. "|r")
	config.simple.tooltip = "Select this if want a simple armory "
	
	config.advanced = CreateFrame("CheckButton", "AMenableButton", config, "InterfaceOptionsCheckButtonTemplate")
	config.advanced:SetPoint("TOPLEFT", config, 100, -150)
	config.advanced:SetHitRectInsets(0, -40, 0, 0)
	config.advancedtitle = config:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	config.advancedtitle:SetFont(GameFontNormal:GetFont(), 14, "OUTLINE")
	config.advancedtitle:SetPoint("LEFT", config.advanced, 30, 0)
	config.advancedtitle:SetText("|cffffffff" .. "Advanced" .. "|r")
	config.advanced.tooltip = "Select this if want an advanced armory "
	
	
	--first group of checkmarks
	config.eubox:SetChecked(options.euEnable)
	config.usbox:SetChecked(options.usEnable)
	config.krbox:SetChecked(options.krEnable)
	config.twbox:SetChecked(options.twEnable)
	
	config.eubox:SetScript("OnClick", 
		   function()
				config.eubox:SetChecked(true)
				config.usbox:SetChecked(false)
				config.krbox:SetChecked(false)
				config.twbox:SetChecked(false)
		   end
		);
	config.usbox:SetScript("OnClick", 
		   function()
				config.eubox:SetChecked(false)
				config.usbox:SetChecked(true)
				config.krbox:SetChecked(false)
				config.twbox:SetChecked(false)
		   end
		);
	config.krbox:SetScript("OnClick", 
		   function()
				config.eubox:SetChecked(false)
				config.usbox:SetChecked(false)
				config.krbox:SetChecked(true)
				config.twbox:SetChecked(false)
		   end
		);
	config.twbox:SetScript("OnClick", 
		   function()
				config.eubox:SetChecked(false)
				config.usbox:SetChecked(false)
				config.krbox:SetChecked(false)
				config.twbox:SetChecked(true)
		   end
		);
		
		
	--second group of checkmarks
	config.simple:SetChecked(options.simple)
	config.advanced:SetChecked(options.advanced)
	config.simple:SetScript("OnClick", 
		   function()
				config.simple:SetChecked(true)
				config.advanced:SetChecked(false)
		   end
		);
	config.advanced:SetScript("OnClick", 
		   function()
				config.simple:SetChecked(false)
				config.advanced:SetChecked(true)
		   end
		);
	
	
	-- finishing config buttons	
	config.okay = function(self)
		ArmoryMeDB.euEnable = getBoolean(config.eubox:GetChecked())
		ArmoryMeDB.usEnable = getBoolean(config.usbox:GetChecked())
		ArmoryMeDB.krEnable = getBoolean(config.krbox:GetChecked())
		ArmoryMeDB.twEnable = getBoolean(config.twbox:GetChecked())
		ArmoryMeDB.simple = getBoolean(config.simple:GetChecked())
		ArmoryMeDB.advanced = getBoolean(config.advanced:GetChecked())
		
		options = ArmoryMeDB				
	end
	
	config.cancel = function(self)
		config.eubox:SetChecked(options.euEnable)
		config.usbox:SetChecked(options.usEnable)
		config.krbox:SetChecked(options.krEnable)
		config.twbox:SetChecked(options.twEnable)
		config.simple:SetChecked(options.simple)
		config.advanced:SetChecked(options.advanced)
	end
	
	config.default = function(self)
		config.eubox:SetChecked(true)
		config.usbox:SetChecked(false)
		config.krbox:SetChecked(false)
		config.twbox:SetChecked(false)
		config.simple:SetChecked(true)
		config.advanced:SetChecked(false)
	end
	
	
	InterfaceOptions_AddCategory(config)
	--end config
	
	--start dialog box
	StaticPopupDialogs["ARMORYME_PLAYERURL"] = {
		text = "This is the Players Armory",
		button1 = "OK",
		OnAccept = function()
			StaticPopup_Hide ("ARMORYME_PLAYERURL")
		end,
		timeout = 0,
		whileDead = true,
		hideOnEscape = true,
		preferredIndex = 3,  -- avoid some UI taint, see http://www.wowace.com/announcements/how-to-avoid-some-ui-taint/
		OnShow = function (self, data)
			self.editBox:SetText(PlayerArmoryURL)
			self.editBox:HighlightText()
		end,
		hasEditBox = true
		}
end


local function constructURLandPrint( playerName, playerRealm )

	PlayerArmoryURL = ""

	if playerRealm == nil then
		playerRealm = GetRealmName()
	end
	
	local currentRegion= ""
	local currentLanguage = ""
	local currentArmoryType = ""
	
	if options.euEnable then
		currentRegion = EU_REGION
		currentLanguage = options.euLang
	end
	if options.usEnable then
		currentRegion = US_REGION
		currentLanguage = options.usLang
	end
	if options.krEnable then
		currentRegion = KR_REGION
		currentLanguage = options.krLang
	end
	if options.twEnable then
		currentRegion = TW_REGION
		currentLanguage = options.twLang
	end
	if options.simple then
		currentArmoryType = "simple"
	end
	if options.advanced then
		currentArmoryType = "advanced"
	end
	
	PlayerArmoryURL = PlayerArmoryURL.."http://"..currentRegion:lower()..".battle.net/wow/"..currentLanguage.."/character/"..playerRealm.."/"..playerName.."/"..currentArmoryType
	
	--print( PlayerArmoryURL )
	StaticPopup_Show ("ARMORYME_PLAYERURL")
	
end

-- hooked to the update method on LFG
local function hook_UpdateApplicantMember(self, ...)
			
			local appID, memberIdx, status = ...
			
			local name, class, localizedClass, level, itemLevel, honorLevel, tank, healer, damage, assignedRole, relationship = C_LFGList.GetApplicantMemberInfo(appID, memberIdx);
			
			self.applicantButton = CreateFrame("Button", "AMapplicantButton", self, "UIPanelButtonGrayTemplate")
			self.applicantButton.playerName = name
			self.applicantButton:SetPoint("TOPLEFT", self, 65, -2)
			self.applicantButton:SetSize(40, 16)
			self.applicantButton:SetText("Armory")
			self.applicantButton:SetHitRectInsets(0, -40, 0, 0)
			self.applicantButton:SetScript("OnClick", function()
			
					local player = mySplit(self.applicantButton.playerName) -- player[1] is name, player[2] is realm
					
					--construct and print URL
					constructURLandPrint(player[1], player[2])
					
					
				end)			
			
end

------------------------
-- EVENT functions
------------------------

frame:RegisterEvent("ADDON_LOADED")

function frame:ADDON_LOADED(addon)
    if addon ~= "ArmoryMe" then return end

    local defaults = {
		euEnable = true,
		euLang = "en",
		usEnable = false,
		usLang = "en",
		krEnable = false,
		krLang = "ko",
		twEnable = false,
		twLang = "zh",
		simple = true,
		advanced = false
	}

	ArmoryMeDB = ArmoryMeDB or {}

	for k,v in pairs(defaults) do
		if ArmoryMeDB[k] == nil then
			ArmoryMeDB[k] = v
		end
	end

	options = ArmoryMeDB	

	SLASH_ARMORYME1, SLASH_ARMORYME2 = "/am", "/armoryme"
	SlashCmdList.ARMORYME = function(msg)
		InterfaceOptionsFrame_Show()
		InterfaceOptionsFrame_OpenToCategory(config)
	end


	frame:RegisterEvent("PLAYER_ENTERING_WORLD")
	frame:RegisterEvent("PLAYER_LOGIN")	

end

function frame:PLAYER_LOGIN()
	--print("|cff3399FF" .. "LOGGED IN" .. "|r")
	setupAMConfig()
end


function frame:PLAYER_ENTERING_WORLD()
	-- LFGListApplicationViewer_UpdateApplicantMember(member, appID, memberIdx, status, pendingStatus)
		hooksecurefunc("LFGListApplicationViewer_UpdateApplicantMember", hook_UpdateApplicantMember)
end
